<?php

/*********************************************************************************

 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2

 * ("License"); You may not use this file except in compliance with the

 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL

 * Software distributed under the License is distributed on an  "AS IS"  basis,

 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for

 * the specific language governing rights and limitations under the License.

 * The Original Code is:  SugarCRM Open Source

 * The Initial Developer of the Original Code is SugarCRM, Inc.

 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;

 * All Rights Reserved.

 * Contributor(s): ______________________________________.

 ********************************************************************************/



$mod_strings = Array(

'LBL_MODULE_NAME'=>'Einstellungen',

'LBL_MODULE_TITLE'=>'Einstellungen: Startseite',

'LBL_LIST_CONTACT_ROLE'=>'Rolle',



'LBL_LIST_LAST_NAME'=>'Nachname',

'LBL_FIRST_NAME'=>'Vorname:',

'LBL_LAST_NAME'=>'Nachname:',

'LBL_PHONE'=>'Telefon:',

'LBL_EMAIL_ADDRESS'=>'E-Mail',

'LBL_TRANSCURR'=>'Transferiere die Währung zu',

'LBL_CURRDEL'=>'Zu löschende Währung',

'LBL_NEW_FORM_TITLE'=>'Neue Person',

'LBL_NEW_CURRENCY'=>'Neue Währung',

'LBL_VIEWING'=>'Ansehen',

'LBL_CURRENCY_NAME'=>'Währungsname',

'LBL_CURRENCY_CODE'=>'Währungscode',

'LBL_CURRENCY_SYMBOL'=>'Symbol',

'LBL_CURRENCY_CRATE'=>'Umrechnungsrate',

'LBL_CURRENCY_STATUS'=>'Status',

'LBL_CURRENCY_TOOL'=>'Werkzeuge',

'LBL_CURRENCY_LIST'=>'Währungsliste',


'NTC_DELETE_CONFIRMATION'=>'Möchten Sie diesen Eintrag löschen?',

'LEADCUSTOMFIELDS'=>'Leads',

'ACCOUNTCUSTOMFIELDS'=>'Organisationen',

'CONTACTCUSTOMFIELDS'=>'Personen',

'OPPORTUNITYCUSTOMFIELDS'=>'Verkaufspotentiale',

'HELPDESKCUSTOMFIELDS'=>'Tickets',

'PRODUCTCUSTOMFIELDS'=>'Produkte',

'VENDORCUSTOMFIELDS'=>'Lieferant',

'PRICEBOOKCUSTOMFIELDS'=>'Preisliste',

'POCUSTOMFIELDS'=>'Bestellungen',
'SOCUSTOMFIELDS'=>'Aufträge',
'QUOTESCUSTOMFIELDS'=>'Angebote',
'INVOICECUSTOMFIELDS'=>'Rechnungen',

'EDITLEADPICKLISTVALUES'=>'Bearbeite Leads',

'EDITACCOUNTPICKLISTVALUES'=>'Bearbeite Organisationen',

'EDITCONTACTPICKLISTVALUES'=>'Bearbeite Personen',

'EDITOPPORTUNITYPICKLISTVALUES'=>'Bearbeite Verkaufspotentiale',

'EDITHELPDESKPICKLISTVALUES'=>'Bearbeite Trouble Tickets',

'EDITPRODUCTPICKLISTVALUES'=>'Bearbeite Produkte',

'EDITEVENTPICKLISTVALUES'=>'Bearbeite Termine/Anrufe',

'EDITTASKPICKLISTVALUES'=>'Bearbeite Aufgaben',

'EDITRSSPICKLISTVALUES'=>'Bearbeite RSS',
'EDITVENDORPICKLISTVALUES'=>'Bearbeite Lieferant',
'EDITPBPICKLISTVALUES'=>'Bearbeite Preisliste',
'EDITPOPICKLISTVALUES'=>'Bearbeite Bestellungen',
'EDITSOPICKLISTVALUES'=>'Bearbeite Aufträge',
'EDITQUOTEPICKLISTVALUES'=>'Bearbeite Angebote',
'EDITINVOICEPICKLISTVALUES'=>'Bearbeite Rechnungen',


// Added for Release vtigerCRM 3.2 PATCH 1.0

//Settings/index.php


'LBL_PICKLIST_FIELD_SETTINGS'=>'Auswahllisten Feldeinstellungen:',



//SETTINGS/CustomFieldList.php,ComboFieldList.php,CreateCustomField.php

'Leads'=>'Lead',

'Accounts'=>'Organisationen',

'Contacts'=>'Personen',

'Potentials'=>'Verkaufspotentiale',

'HelpDesk'=>'HelpDesk',

'Products'=>'Produkte',

'Events'=>'Ereignisse',

'Activities'=>'Aktivitäten',





'CustomFields'=>'Benutzerdefinierte Felder',

'NewCustomField'=>'Neues benutzerdefiniertes Feld',

'NewCustomFieldAltC'=>'Neuese benutzerdefiniertes Feld [Alt+C]:',

'FieldName'=>'Feldname',

'FieldType'=>'Feldtyp',

'FieldLabel'=>'Feldlabel',

'Delete'=>'Lö',

'NEW'=>'Neu',

'CUSTOMFIELD'=>'Benutzerdefiniertes Feld',

'LBL_CUSTOM_FIELDS'=>'Benutzerdefinierte Felder',

'LBL_ADD_FIELD'=>'Feld hinzufügen',

'LBL_CUSTM_MSG'=>'erlaubt zu ....',

'PicklistFields'=>'Auswahllistenfeld',


'Edit'=>'Bearbeiten',

'LBL_EDIT_FIELD_TYPE'=>'Bearbeite Feldtyp',

//Settings/CustomField.html

'LBL_PROVIDE_FIELD_INFORMATION'=>'Definitionen für neues Feld: ',

'LBL_SELECT_FIELD_TYPE'=>'Typ: ',

'LBL_PROVIDE_FIELD_DETAILS'=>'Details: ',

'LBL_LABEL'=>'Bezeichnung: ',

'LBL_LENGTH'=>'Länge: ',

'LBL_DECIMAL_PLACES'=>'Dezimalstellen: ',

'LBL_PICK_LIST_VALUES'=>'Werte der Auswahlliste: ',



//Settings/EditComboField.php

'EditPickListValues'=>'Bearbeite Auswahlliste',



//Settings/EditField.html

'LBL_FIELD_INFORMATION'=>'Feldinformation:',

'Values'=>'Werte',

'EnterListOfValues'=>'Werte unten eingeben. Jeder Wert muss in einer einzelnen Zeile stehen.',



//Settings/fieldtypes.php

'Text'=>'Text',

'Number'=>'Zahl',

'Percent'=>'Prozent',

'Currency'=>'Währung',

'Date'=>'Datum',

'Email'=>'E-Mail',

'Phone'=>'Telefon',

'PickList'=>'Auswahlliste',

'LBL_MULTISELECT_COMBO'=>'Multi-Auswahl Box',

'Skype'=>'Skype',



//added for patch2

'USERGROUPLIST'=>'Gruppen',

'EMAILTEMPLATES'=>'E-Mail Vorlagen',

'WORDINTEGRATION'=>'Textvorlagen',

'LBL_MAIL_MERGE'=>'Textvorlagen',

'NOTIFICATIONSCHEDULERS'=>'Benachrichtigungen',
//currency status
'LBL_ACTIVE'=>'Aktiv',

'LBL_INACTIVE'=>'Inaktiv',

'LBL_NOTIFICATION'=>'Benachrichtigung',
'LBL_DESCRIPTION'=>'Beschreibung',
'LBL_TOOL'=>'Werkzeug',


//Added fields for Title Informations -- after 4 Beta

'LBL_EMAIL_CONFIG'=>'E-Mail Server Konfiguration',

'LBL_WORD_INTEGRATION'=>'Word Integration:',

'LBL_GROUP_SETTINGS'=>'Gruppen Einstellungen:',

'LBL_TEMPLATE_SETTINGS'=>'Vorlagen Einstellungen:',

'LBL_NOTIFICATION_SETTINGS'=>'Benachrichtigungen Einstellungen:',

'LBL_EMAIL_SETTINGS'=>'E-Mail Einstellungen:',

'LBL_SECURITY_SETTINGS'=>'Sicherheits Einstellungen:',



//Added fields after RC1 - Release

'LBL_MAIL_SERVER_INFO'=>'Information über ausgehenden Mailserver',

'LBL_OUTGOING_MAIL_SERVER'=>'Servername',

'LBL_OUTGOING_MAIL_SERVER_LOGIN_USER_NAME'=>'Benutzername für Mailserver',

'LBL_OUTGOING_MAIL_SERVER_PASSWORD'=>'Passwort für Mailserver',

'LBL_MAIL_SERVER_SMTP'=>'Mail Server (SMTP)',

'LBL_BACKUP_SERVER_CONFIG'=>'Backup Server',

'LBL_SERVER_ADDRESS'=>'Server Adresse',

'LBL_FTP_SERVER_NAME'=>'ftp Servername',

'LBL_FTP_USER_NAME'=>'ftp Nutzername',

'LBL_FTP_PASSWORD'=>'ftp Passwort',

'LBL_FTP'=>'FTP',

'LBL_SYSTEM_CONFIG'=>'Systemkonfiguration',
'LBL_SYSTEM_INFO'=>'Systeminformation',
'LBL_PROXY_SETTINGS'=>'Proxy Server Einstellungen',
'LBL_AUDIT_TRAIL'=>'Audit Trail',
'LBL_ENABLE_AUDIT_TRAIL'=>'Audit Trail zulassen',
'LBL_USER_AUDIT'=>'Nutzer auswählen',
'LBL_VIEW_AUDIT_TRAIL'=>'Audit Trail ansehen',
'LBL_AUDIT_TRAIL_DESC'=>'zeige den Audit Trail von Nutzern, die das CRM System genutzt haben',
'LBL_NO_DATA'=>'Keine Daten vorhanden',

'LBL_CURRENCY_CONFIGURATION'=>'- Währungen',

'LBL_CURRENCY_CONFIG'=>'Währungen',

'LBL_CURRENCY_INFO'=>'Währungen',

'LBL_CURRENCY_TITLE'=>'Währungen',

'LBL_CURRENCY_SETTINGS'=>'Währungseinstellungen',


'LBL_USERNAME'=>'Nutzername',
'LBL_PASWRD'=>'Passwort',
'LBL_REQUIRES_AUTHENT'=>'Authentifikation erforderlich?',
'LBL_FROM_EMAIL_FIELD'=>'von E-Mail',

//Fields for Settings

'LBL_USER_MANAGEMENT'=>'Benutzerverwaltung',

'LBL_USERS'=>'Benutzer',

'LBL_USERS_LIST'=>'Benutzerliste',
'LBL_GROUP_LIST'=>'Gruppenliste',

'LBL_CREATE_AND_MANAGE_USERS'=>'- Erstellen und Verwalten von Benutzern (z.B. admin)',


'LBL_CREATE_AND_MANAGE_USER_ROLES'=>'- Erstellen und Verwalten von Rollen (z.B. Administrator, Sekretariat, usw.)',

'LBL_PROFILES'=>'Profile',

'LBL_PROFILES_LIST'=>'Profilliste',

'LBL_CREATE_AND_MANAGE_USER_PROFILES'=>'- Erstellen und Verwalten von Benutzerprofilen (z.B., Vertrieb, Service, usw.)',

'LBL_CREATE_AND_MANAGE_USER_GROUPS'=>'- Erstellen und Verwalten von Benutzergruppen',

'LBL_SHARING_ACCESS'=>'Globale Rechtevergabe',

'LBL_FIELDS_ACCESS'=>'Globale Standardfelder',

'LBL_DEFAULT_ORGANIZATION_FIELDS'=>'Globaler Zugang auf Standardfelder',

'LBL_SETTING_DEFAULT_ORGANIZATION_FIELDS'=>' - Ein-/Ausschalten der Sichtbarkeit der Standardfelder',

'LBL_SETTING_DEFAULT_SHARING_ACCESS'=>'- Setzt die Berechtigung auf Module',

'LBL_FIELD_ACCESSIBILITY'=>'Feldzugangsmöglichkeit',

'LBL_SETTING_FIELD_ACCESSIBILITY'=>' - Setzt die Zugriffsrechte auf Felder für jedes Profil',
//<<<<<<<<for edit ordering blocks>>>>>>
'LBL_FIELD_ORDERING_DESC'=>' - Bearbeite Feld Reihenfolge',

'LBL_FIELD_ORDERING'=>'Bearbeite Feldblöcke',
//<<<<<<<<<<end>>>>>>>>>>>>>
'LBL_LEAD_FIELD_ACCESS'=>'Leads',

'LBL_ACCOUNT_FIELD_ACCESS'=>'Organisationen',

'LBL_CONTACT_FIELD_ACCESS'=>'Personen',

'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Verkaufspotentiale',

'LBL_HELPDESK_FIELD_ACCESS'=>'HelpDesk',

'LBL_PRODUCT_FIELD_ACCESS'=>'Produkte',

'LBL_NOTE_FIELD_ACCESS'=>'Notizen',

'LBL_EMAIL_FIELD_ACCESS'=>'E-Mail',

'LBL_TASK_FIELD_ACCESS'=>'Aufgaben',

'LBL_EVENT_FIELD_ACCESS'=>'Termine/Anrufe',

'LBL_DELETE_DEMO_DATA'=>'Lösche Demodaten',

'LBL_DELETE_DEMO_DATA_INFO'=>'- Löscht die Demodaten, welche während der Installation angelegt wurden.',



'LBL_STUDIO'=>'Studio',

'LBL_CUSTOM_FIELD_SETTINGS'=>'Benutzerdefinierte Felder',

'LBL_CREATE_AND_MANAGE_USER_DEFINED_FIELDS'=>'Bearbeiten der globalen benutzerdefinierten Felder',

'LBL_SELECT_MODULE'=>'Modul auswählen',

'LBL_SELECT_CF_TEXT'=>'<b>Modul auswählen:</b>',



'LBL_PICKLIST_SETTINGS'=>'Auswahllisten',

'LBL_EDIT_PICKLIST_VALUES'=>' - Bearbeiten der Felder in den Auswahllisten',

'LBL_EDIT'=>'bearbeite',

'LBL_COMMUNICATION_TEMPLATES'=>'Vorlagen',

'LBL_CREATE_EMAIL_TEMPLATES'=>' - Erstellen von E-Mail Vorlagen',

'LBL_UPLOAD_MSWORD_TEMPLATES'=>' - Upload von MS Word Vorlagen',

'LBL_SCHEDULE_EMAIL_NOTIFICATION'=>' - Konfigurieren von automatischen Benachrichtigungen',

'LBL_EXPAND_CLOSE_MENU'=>'Menü Expandieren/Schließen',

'LBL_CONFIGURATION'=>'Konfiguration',

'LBL_CONFIGURE_MAIL_SERVER'=>' - Konfiguriere Mail Server',

'LBL_BACKUP_SERVER_CONFIGURATION'=>'Backup Server Konfiguration',

'LBL_BACKUP_SERVER_INFO'=>'Backup Server Information',

'LBL_BACKUP_SERVER_SETTINGS'=>'Backup Server Einstellungen',

'LBL_CONFIGURE_BACKUP_SERVER'=>' - Konfiguriere Backup Server',

'LBL_SYSTEM_CONFIGURATION'=>' - Systemkonfiguration',

'LBL_PROXY_SERVER_CONFIGURATION'=>'Proxy Server Konfiguration',

'LBL_PROXY_SERVER_INFO'=>'Proxy Server Information',

'LBL_PROXY_SERVER_SETTINGS'=>'Proxy Server Einstellungen',

'LBL_CONFIGURE_PROXY_SERVER'=>' - Konfiguriere Proxy Server',

'LBL_PROXY_PORT'=>'Port Nummer',



//Field Types for custom fields

'LBL_URL'=>'URL',

'LBL_CHECK_BOX'=>'Checkbox',



//PickList Settings

'LBL_STANDARD_FIELDS'=>'Standard Felder',

'LBL_LEAD_SOURCE'=>'Leadquelle',

'LBL_SALUTATION'=>'Anrede',

'LBL_LEAD_STATUS'=>'Leadstatus',

'LBL_INDUSTRY'=>'Industrie',

'LBL_RATING'=>'Bewertung',

'LBL_ACCOUNT_TYPE'=>'Organisationstyp',

'LBL_BUSINESS_TYPE'=>'Geschäftsbeziehung',

'LBL_CURRENCY_TYPE'=>'Währungstyp',

'LBL_SALES_STAGE'=>'Verkaufsphase',

'LBL_PRIORITY'=>'Priorität',

'LBL_STATUS'=>'Status',

'LBL_CATEGORY'=>'Kategorie',

'LBL_MANUFACTURER'=>'Hersteller',

'LBL_PRODUCT_CATEGORY'=>'Produktkategorie',

'LBL_RSS_CATEGORY'=>'RSS Kategorie',

//Added for Web based Email client integration (post 4.0.1 release)

'LBL_ADD_MAIL_ACCOUNT'=>'E-Mail Konto hinzufügen',
'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Neues E-Mail Konto [Alt+M]',
'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Neues E-Mail Konto',
'LBL_GENERAL_INFO'=>'Allgemein',
'LBL_DISPLAY_NAME'=>'Anzeigename',
'LBL_MAIL_PROTOCOL'=>'Mail-Protokoll',
'LBL_LIST_PASSWORD'=>'Passwort',
'LBL_MAIL_SERVER_NAME'=>'Mail-Servername oder IP',
'LBL_MAIL_SERVER_SETTINGS'=>'Mailserver',
'LBL_INCOME_SERVER_SETTINGS'=>'Posteingangsserver',
'LBL_TEST_SETTINGS'=>'Einstellungen testen',
'LBL_TEST_BUTTON_TITLE'=>'Einstellungen testen! [Alt+T]',
'LBL_TEST_BUTTON_KEY'=>'T',
'LBL_TEST_BUTTON_LABEL'=>'Einstellungen testen!',
'LBL_DEFAULT'=>'Default',
'LBL_IMAP2'=>'IMAP2',
'LBL_IMAP4'=>'IMAP4',
'LBL_POP'=>'POP',
'LBL_IMAP'=>'IMAP',
'LBL_MAIL_DISCLAIM'=>'Einträge mit einer <font color="red">*</font> Markierung sind Pflichtangaben<br>Einträge mit einer <font color="red">* *</font> Kennzeichnung werden nicht voll unterstützt',
'LBL_SSL_OPTIONS'=>'SSL Optionen',
'LBL_TLS'=>'TLS',
'LBL_NO_TLS'=>'Kein TLS',
'LBL_CERT_VAL'=>'Zertifikatsvalidierung',
'LBL_INT_MAILER'=>'internes Mailprogramm benutzen?',
'LBL_INT_MAILER_USE'=>'Ja',
'LBL_INT_MAILER_NOUSE'=>'Nein',
'LBL_VAL_SSL_CERT'=>'validiere SSL Zertifikat',
'LBL_DONOT_VAL_SSL_CERT'=>'ohne Zertifikat Validierung',
'LBL_WEB_MAIL_CONFIG'=>'WebMail-Konfiguration',
'LBL_CONFIGURE_WEB_MAIL'=>' - Konfiguriere WebMail',
'LBL_LIST_MAIL_ACCOUNT'=>'  Liste der Mail Konten',
'LBL_USAGEUNIT'=>'Einheit',
'LBL_GLACCT'=>'FiBu Konto',
'LBL_QUOTE_STAGE'=>'Angebotsstufe',
'LBL_CARRIER'=>'Transporteur',
'LBL_TAXCLASS'=>'Steuerklasse',
'LBL_MY_DETAILS'=>'Meine Details',
'LBL_MY_MAIL_SERVER_DET'=>'Meine Mailserver Details',
'LBL_EMAIL_ID'=>'Email ID',
'LBL_NAME_EXAMPLE'=>'(Beispiel : Hans Mustermann)',
'LBL_EMAIL_EXAMPLE'=>'(Beispiel : hmusterman@mailserver.com)',
'LBL_REFRESH_TIMEOUT'=>'Refresh Timeout',
'LBL_1_MIN'=>'1 Minute',
'LBL_2_MIN'=>'2 Minuten',
'LBL_3_MIN'=>'3 Minuten',
'LBL_4_MIN'=>'4 Minuten',
'LBL_5_MIN'=>'5 Minuten',
'LBL_EMAILS_PER_PAGE'=>'E-Mails pro Seite',

//Added for Organization Details (4.2 release)
'LBL_ORGANIZATION_NAME'=>'Organisation',
'LBL_ORGANIZATION_ADDRESS'=>'Addresse',
'LBL_ORGANIZATION_CITY'=>'Ort',
'LBL_ORGANIZATION_STATE'=>'Bundesland',
'LBL_ORGANIZATION_CODE'=>'PLZ',
'LBL_ORGANIZATION_COUNTRY'=>'Land',
'LBL_ORGANIZATION_PHONE'=>'Telefon',
'LBL_ORGANIZATION_FAX'=>'Fax',
'LBL_ORGANIZATION_WEBSITE'=>'Webseite',
'LBL_ORGANIZATION_DETAILS'=>'Details',
'LBL_SPECIFY_COMPANY_DETAILS'=>' - spezifizieren von Firmeninformationen',
'LBL_ORGANIZATION_LOGO'=>'Logo Name',
'LBL_UPLOAD'=>'Upload',
'LBL_FILENAME'=>'Dateiname',
'LBL_SETTINGS'=>'Einstellungen',
'LBL_COMPANY_DETAILS'=>'Unternehmensinformation',

'LBL_SEVERITY'=>'Wichtigkeit',
'LBL_FAQ_CATEGORY'=>'Wissensbank Kategorie',
'LBL_VENDOR_FIELD_ACCESS'=>'Lieferant Feldzugang',
'LBL_PB_FIELD_ACCESS'=>'Preisliste Feldzugang',
'LBL_QUOTE_FIELD_ACCESS'=>'Angebote Feldzugang',
'LBL_PO_FIELD_ACCESS'=>'Bestellungen Feldzugang',
'LBL_SO_FIELD_ACCESS'=>'Aufträge Feldzugang',
'LBL_INVOICE_FIELD_ACCESS'=>'Rechnungen Feldzugang',
'INVENTORYNOTIFICATION'=>'Bestandsnachrichten',
'LBL_INVENTORY_NOTIFICATIONS'=>'Bearbeite Bestandsnachrichten',
'INVENTORYTERMSANDCONDITIONS'=>'Geschäftsbedingungen',//newly added for Inventory terms and conditions
'LBL_INVENTORY_TERMSANDCONDITIONS'=>' - Bearbeite Geschäftsbedingungen',//newly added
'LBL_TANDC_TEXT'=>'Text für Geschäftsbedingungen',
'LBL_INVENTORY_TANDC'=>'Geschäftsbedingungen',

'LBL_OTHER_SETTINGS'=>'Andere Einstellungen',
'LBL_SCROLL'=>'[Nach Oben]',

'LBL_INV_NOT_DESC'=>'Hier finden Sie eine Liste aller Nachrichten, die an den verantwortlichen Nutzer hinsichtlich der Veränderung Ihres Bestandes an Waren in Folge der Erstellung von Angeboten, Verkaufsbestellungen und Rechnungen gesendet wurden.',

'InvoiceNotification'=>'Bestandsnachrichten während Rechnungserstellung',
'InvoiceNotificationDescription'=>'Wenn der Bestand den Minimalbestand erreicht hat, wird eine Nachricht an den Einkäufer gesendet.',
'Vendor'=>'Verkäufer',
'PriceBook'=>'Preisliste',
'Quotes'=>'Angebot',
'PurchaseOrder'=>'Einkauf',
'SalesOrder'=>'Verkauf',
'Invoice'=>'Rechnung',

//For Custom Fields
'LBL_LEAD_MAP_CUSTOM_FIELD'=>'Feldzuweisung der benutzerdefinierten Felder in Leads',
'leadCustomFieldDescription'=>'Weisen Sie Ihren benutzerdefinierten Feldern aus dem Modul
Leads entsprechende benutzerdefinierten Felder aus den Modulen Personen, Organisationen und Verkaufspotentialen zu. Hinweis: Diese Zuordnungen stehen erst nach der Umwandlung eines Leads in ein Verkaufspotential zur Verfügung!',
'LBL_MAPPING_INFO'=>'Zuordnungen',
'LBL_ACCOUNT_FIELD'=>'Organisationen Feld',
'LBL_CONTACT_FIELD'=>'Personen Feld',
'LBL_POTENTIAL_FIELD'=>'Verkaufspotentiale Feld',
'CUSTOMFIELDMAPPING'=>'Zuordnungen der benutzerdefinierten Felder',
'LBL_FIELD_MAPPING'=>'Feldzuordnung',
'LBL_LEAD_FIELD'=>'Lead Feld',
//After 4.2 GA
'LBL_TEXT_AREA'=>'Text Bereich',
//for Edit ordering the blocks
'NOTESCUSTOMFIELDS'=>'Notizen angepasste Felder',

//Added fields after 4.2 ptach 2
'LBL_ASSIGN_MODULE_OWNERS'=>'Modulen Besitzer zuweisen',
'LBL_MODULE_OWNERS'=>'Modulbesitzer',
'LBL_ASSIGN_MODULE_OWNERS_INFO'=>' - weise einen Besitzer für jedes Modul zu',
'LBL_MODULE'=>'CRM Module',
'LBL_OWNER'=>'Besitzer',
'LBL_MIGRATION'=>'Migriere von vorhergehender Version',
'LBL_MIGRATION_INFO'=>' - Migration von vorhergehenden Version',

//Added for 5 GA - Description of Settings UI

'LBL_USER_DESCRIPTION'=>'bearbeiten Sie die CRM Benutzerliste und weisen Sie Benutzern Rollen zu',
'LBL_ROLE_DESCRIPTION'=>'definieren Sie die Hierarchie von Rollen und weisen Sie diesen Profile zu',
'LBL_PROFILE_DESCRIPTION'=>'definieren Sie Profile als Basis für die Rechtevergabe an Nutzern über Rollen',
'LBL_GROUP_DESCRIPTION'=>'definieren Sie Gruppen auf der Basis von Rollen, Nutzern, Profilen usw.',
'LBL_SHARING_ACCESS_DESCRIPTION'=>'definieren Sie die unternehmensweit gültigen Zugangsrechte, die für jede Rolle gelten',
'LBL_SHARING_FIELDS_DESCRIPTION'=>'entscheiden Sie, welche Felder in den CRM Modulen angezeigt werden sollen',
'LBL_MODULE_OWNERS_DESCRIPTION'=>'setzen Sie die Besitzer für die CRM Module',
'LBL_ANNOUNCEMENT_DESCRIPTION'=>'bearbeiten Sie den Inhalt der Anzeige von Bekanntgaben',
'LBL_CUSTOM_FIELDS_DESCRIPTION'=>'bearbeiten oder erstellen Sie benutzerdefinierte Felder',
'LBL_PICKLIST_DESCRIPTION'=>'bearbeiten Sie den Inhalt der Auswahllisten in den CRM Modulen',
'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'bearbeiten Sie die Vorlagen für das E-Mail Modul',
'LBL_MAIL_MERGE_DESCRIPTION'=>'bearbeiten Sie die Vorlagen für das Zusammenführen von Dokumenten',
'LBL_NOTIF_SCHED_DESCRIPTION'=>'bearbeiten Sie die Benachrichtigungen, die bei wichtigen Ereignissen automatisch aus vom CRM versendet werden',
'LBL_INV_NOTIF_DESCRIPTION'=>'ändern Sie die Einstellungen zu den Benachrichtigungen über den Lagerbestand',
'LBL_INV_TANDC_DESCRIPTION'=>'bearbeiten Sie den Text für die Geschäftsbedingungen',
'LBL_COMPANY_DESCRIPTION'=>'bearbeiten Sie die Ihre Unternehmensinformationen',
'LBL_MAIL_SERVER_DESCRIPTION'=>'bearbeiten Sie die Einstellungen für den E-Mail Server',
'LBL_BACKUP_SERVER_DESCRIPTION'=>'bearbeiten Sie die Einstellungen für den Backup Server',
'LBL_CURRENCY_DESCRIPTION'=>'bearbeiten Sie die Einstellungen für Währungen und Umtauschkurs',
'LBL_TAX_DESCRIPTION'=>'bearbeiten Sie die Einstellungen für die Mwst. und anderen Steuern',
'LBL_SYSTEM_DESCRIPTION'=>'Systemeinstellungen anzeigen',
'LBL_PROXY_DESCRIPTION'=>'bearbeiten Sie die Einstellungen für den Zugang zum Internet',
'LBL_AUDIT_DESCRIPTION'=>'Audit-Trail Informationen bearbeiten und anzeigen',
'LBL_TAX_DESC'=>'bearbeiten Sie die Einstellungen für die Mwst. und anderen Steuern',
'LBL_COMPANY_DESC'=>'Informationen & Kontaktdetails Ihres Unternehmens',
'LBL_SELECT_LOGO'=>'neues Logo auswählen:',
'LBL_INVEN_TANDC_DESC'=>'bearbeiten Sie den Text der Geschäftsbedingungen, wie dieser in den produktbezogenen Modulen angezeigt wird.',
'LBL_MAIL_SERVER_DESC'=>'bearbeiten Sie die E-Mail Server Einstellungen für alle ausgehenden E-Mails. An die E-Mail Adresse des CRM Administrators wird danach eine E-Mail aus dem CRM zur Bestätigung der Verbindung zu Ihrem Server gesendet.',
'LBL_BACKUP_SERVER_DESC'=>'bearbeiten Sie die Backup Server Einstellungen',
'LBL_MODULES_AND_OWNERS'=>'Module & Besitzer',
'LBL_GROUP_DESC'=>'bearbeiten Sie die Nutzergruppen',
'LBL_MAIL_MERGE_DESC'=>'bearbeiten Sie die Vorlagen für das Zusammenführen von Dokumenten',


//Added fields after 5.0 Alpha
'LBL_REQUIRE_SMTP_AUTHENTICATION'=>'SMTP Authentifizierung verlangen?',
'LBL_ANNOUNCEMENT'=>'Bekanntgaben',
'LBL_SETTING_ANNOUNCEMENT'=>'Bekanntgabe',
'LBL_ANNOUNCE_TEXT'=>'Bekanntgabetext',
'LBL_UPDATE_BUTTON'=>'Aktualisieren',
'LBL_ANNOUNCEMENT_INFO'=>'Bitte Bekanntgabe eingeben und auf den -Aktualisieren- Button klicken.',
'LBL_ANNOUNCEMENT_DESC'=>'Ändern Sie den Text der im oberen Bereich auf jeder Seite als Bekanntgabe angezeigt wird.',
'LBL_EMAIL_CONTENTS'=>'E-Mail Inhalte',
'LBL_SUBJECT'=>'Betreff',
'LBL_MESSAGE'=>'Nachricht',
'LBL_PICKLIST_EDITOR'=>'Auswahllisten Editor',
'LBL_PICKLIST_AVAIL'=>'Auswahllisten verfügbar in',
'LBL_PICKLIST_AVAILINFO1'=>'Die verfügbaren Auswahllisten in ',
'LBL_PICKLIST_AVAILINFO2'=>'werden hier gezeigt.',
'LBL_EDIT_PICKLIST'=>'Bearbeite Auswahlliste',
'LBL_PICKLIST_SAVEINFO'=>'Geben Sie die Eingaben einzeln ein und speichern Sie diese.',
'LBL_SELECT_CRM_MODULE'=>'CRM Modul auswählen',
'LBL_TAX_SETTINGS'=>'Einstellungen Steuern',
'LBL_INVENTORY_TAX_CONFIG'=>'Konfiguration der Steuern',
'LBL_CUSTOM_MAPP_INFO'=>'Nur Felder aus Leads können mit anderen Feldern verbunden werden.',
'LBL_MAPPING_OTHER_MODULES'=>'Mit anderen Modulen verbinden',
'LBL_CUSTOM_FILED_IN'=>'Benutzerdefinierte Felder in ',
'LBL_ROLE_HIERARCHY_TREE'=>'Rolle- und Hierarchiebaum',
'LBL_EDIT_FIELD_MAPPING'=>'Feldverbindungen bearbeiten',
'LBL_LOGIN_HISTORY_DETAILS'=>'Details der Login-Historie',
'LBL_LOGIN_HISTORY_DESCRIPTION'=>'Login-Historie für alle Nutzer anzeigen',
'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'Nicht bearbeitbare Auswahllisteneinträge',

//Added for Tax settings
'LBL_PRODUCT_TAX_SETTINGS'=>'Steuern auf Produkte/Dienstleistungen',
'LBL_SHIPPING_HANDLING_TAX_SETTINGS'=>'Steuern auf Versandkosten',
'LBL_PROXY_SERVER_DESC'=>'Konfiguriere Proxies um RSS Feeds über das Internet zu erreichen',

'LBL_NEW_CURRENCTY'=>'Neue Währung',
'LBL_BASE_CURRENCY'=>'Basiswährung - ',
'LBL_DELETE_CURRENCY'=>'Währung löschen',

//Added for singlepane view in modules

'LBL_DEFAULT_DETAIL_VIEW'=>'Standarddetailansicht',
'LBL_DEFAULT_MODULE_VIEW'=>'Standard Modulansicht',
'LBL_DEFAULT_MODULE_VIEW_DESC'=>'setzen Sie die Standarddetailansicht für alle Module',
'LBL_ENABLE_SINGLEPANE_VIEW'=>'zur kompakten Detailansicht wechseln',

'LBL_CLEAR_DATA'=>'Daten löschen',
'LBL_ENABLE'=>'zulassen',
'LBL_FAQ_FIELD_ACCESS'=>'Wissensbasis Feldzugang',
'LBL_ADD_TAX_BUTTON'=>'Steuer hinzufügen',
'LBL_NO_TAXES_AVAILABLE'=>'keine Steuern verfügbar',
'LBL_PLEASE'=>'Bitte',
//Added while moving role file from User to Setting Module
'LBL_ROLES'=>'Rollen',
'LBL_CREATE_NEW_ROLE'=>'Neue Rolle erstellen',
'LBL_PROPERTIES'=>'Eigenschaften: ',
'LBL_NEW_ROLE'=>'Neue Rolle',
'LBL_ROLE_NAME'=>'Rollenname',
'LBL_REPORTS_TO'=>'Vorgesetzter',
'LBL_PROFILE_M'=>'Profil',
'LBL_PROFILES_AVLBL'=>'Verfügbare Profile',
'LBL_ASSIGN_PROFILES'=>'Zugewiesene Profile',
'LBL_MEMBER'=>'Mitglieder',
'LBL_DELETE_ROLE'=>'Lösche Rolle',
'LBL_ROLE_TO_BE_DELETED'=>'zu löschende Rolle',
'LBL_TRANSFER_USER_ROLE'=>'Übergebe Rolle an Benutzer',
'LBL_ASSOCIATED_PROFILES'=>'Bezogene Profile :',
'LBL_ASSOCIATED_USERS'=>'Bezogene Nutzer :',
//Added while moving email templates from Users to Settings
'LBL_EMAIL_TEMPLATES'=>'E-Mail Vorlagen',
'LBL_EMAIL_TEMPLATE_DESC'=>'Manage E-Mail Vorlagen für Massenmails und Kampagnen',
'LBL_LIST_SELECT'=>'Auswählen',
'LBL_EMAIL_TEMPLATE'=>'E-Mail Vorlage',
'LBL_TEMPLATE_TOOLS'=>'Werkzeuge',
'LBL_NEW_TEMPLATE' =>'Neue Vorlage',
'LBL_FOLDER'=>'Verzeichnis',
'LBL_NAME'=>'Name',
'LBL_PERSONAL'=>'Personal',
'LBL_PUBLIC'=>'Öffentlich',
'LBL_ACCOUNT_FIELDS'=>'Organisationsfelder',
'LBL_CONTACT_FIELDS'=>'Personenfelder',
'LBL_LEAD_FIELDS'=>'Leadfelder',
'LBL_USER_FIELDS'=>'Nutzerfelder',
'LNK_SAMPLE_EMAIL'=>'Beispiel E-Mail ansehen',
//Added while moving Mail Merge templates from Users to Settings
'LBL_TEMPLATE_FILE'=>'Vorlagedatei',
'LBL_MODULENAMES'=>'Modul',
'LBL_DOWNLOAD'=>'Download',
'LBL_ADD_TEMPLATE'=>'erstelle Vorlage',
'LBL_WORD_TEMPLATES'=>'Textvorlage',
//Added while moving Notification Schedulers from Users to Settings
'LBL_TASK_NOTIFICATION'=>'Aufgabe verspätet',
'LBL_BIG_DEAL'=>'keine Benachrichtigung',
'LBL_PENDING_TICKETS'=>'offene Tickets',
'LBL_MANY_TICKETS'=>'zu viele Tickets',
'LBL_START_NOTIFICATION'=>'automatische Benachrichtigung an Personen',
'LBL_ACTIVITY_NOTIFICATION'=>'Ereignisbenachrichtigung',

'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Aufgabe um mehr als 24h verspätet',
'LBL_BIG_DEAL_DESCRIPTION'=>'für zukünftige Verwendung reserviert',
'LBL_TICKETS_DESCRIPTION'=>'Statusmeldung über offene Tickets',
'LBL_MANY_TICKETS_DESCRIPTION'=>'Zu viele Tickets bei einem Vorfall; könnte darauf hinweisen, dass Servicelevel nicht eingehalten werden kann',
'LBL_START_DESCRIPTION'=>'das ist die E-Mail, die an eine Person versendet wird, sobald das Kundenportal für diese Person freigeschaltet wird',
'LBL_ACTIVITY_REMINDER_DESCRIPTION'=>'Erinnere vor einem Ereignis entsprechend der Zeitplanung',
//Added while moving Inventory Notifications from Users to Settings
'QuoteNotificationDescription'=>'Diese Nachricht wird versendet, wenn der Lagerbestand kleiner ist, als die Anzahl der im Angebot aufgeführten Produkte.',
'SalesOrderNotificationDescription'=>'Diese Nachricht wird versendet, wenn der Lagerbestand kleiner ist als die Menge, welche im Verkauf angegeben wurde.',
'Tools'=>'Werkzeuge',
'QuoteNotification'=>'Lagerbestandsmeldung zur Angebotserstellung',
'SalesOrderNotification'=>'Lagerbestandsmeldung zum Verkauf',
'LBL_NOTE_DO_NOT_REMOVE_INFO'=>'Hinweis: Die Werte innerhalb {  } nicht verändern.',

//Added while moving Profile file from User to Setting Module
'LBL_TOTAL'=>'Total :',
'LBL_NEW_PROFILE'=>'Neues Profil',
'LBL_LIST_NO'=>'#',
'LBL_NEW_PROFILE_NAME'=>'Profilname',
'LBL_LIST_TOOLS'=>'Werkzeuge',
'LBL_PROFILE_MESG'=>'Die Zugangsrechte ansehen für',
'LBL_PROFILE_PRIVILEGES'=>'Profilprivilegien',
'LBL_DEFINE_PRIV_FOR'=>' Definiere Privilegien für ',
'LBL_USE_OPTION_TO_SET_PRIV'=>'Benutzen Sie die nachfolgenden Optionen, um Privilegien zu setzen.',
'LBL_SUPER_USER_PRIV'=>'Übergeordnete Nutzerprivilegien',
'LBL_SET_PRIV_FOR_EACH_MODULE'=>'Setze Privilegien für jedes Modul ',
'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Feld- & Werkzeugprivilegien',
'LBL_VIEW_ALL'=>'Alle Ansehen',
'LBL_EDIT_ALL'=>'Alle Bearbeiten',
'LBL_ALLOW'=>'Erlaubt',
'LBL_MESG_VIEW'=>'alle Informationen/Module zu sehen',
'LBL_MESG_EDIT'=>'alle Informationen/Module zu bearbeiten',
'LBL_TAB_MESG_OPTION'=>'Module die angezeigt werden sollen',
'LBL_CREATE_EDIT'=>'Erstellen/Bearbeiten',
'LBL_VIEW'=>'Ansehen',
'LBL_MANDATORY_MSG'=>'Pflichtfelder',
'LBL_DISABLE_FIELD_MSG'=>'Felder durch die Einstellungen in Globaler Rechtevergabe gesperrt.',
'LBL_DELETE'=>'Löschen',

'LBL_STEP_2_2'=>'Schritt 2 von 2',
'LBL_FINISH_BUTTON'=>'Beenden',

//Added while moving Groups file from User to Setting Module
'LBL_NEW_GROUP'=>'Neue Gruppe',
'LBL_GROUPS'=>'Gruppen',
'LBL_GROUP_NAME'=>'Gruppenname',
'LBL_ROLES_SUBORDINATES'=>'Rollen und Unterstellte',
'LBL_MEMBER_AVLBL'=>'Verfügbare Mitglieder',
'LBL_MEMBER_SELECTED'=>'Ausgewählte Mitglieder',
'LBL_ENTITY'=>'Einheit',
'LBL_OF'=>'von',
'LBL_CREATE_NEW_GROUP'=>'Neue Gruppe erstellen',
'LBL_ADD_GROUP_BUTTON'=>'Gruppe hinzufügen',
'LBL_GROUP_MESG1'=>'Gruppen sind sehr zweckmäßig, um in komplexen Organisationen Rechte zu vergeben. Sie können Rollen, Nutzer, Profile und auch existierende Gruppen zu neuen Gruppen zusammenfassen.',
'LBL_GROUP_MESG2'=>'Um eine Gruppenmitglied hinzuzufügen, wählen Sie links die Quelle und klicken Sie auf den ">>" Button.',
'LBL_GROUP_MESG3'=>'Um ein Gruppenmitglied zu entfernen, wählen Sie rechts ein Gruppenmitglied und klicken Sie auf den "<<" Button.',

//Sharing Privileges
'LBL_GLOBAL_ACCESS_PRIVILEGES'=>'Globale Zugangsregeln',
'LBL_RECALCULATE_BUTTON'=>'Neu Berechnen',
'LBL_CHANGE'=>'Bearbeiten',
'LBL_PRIVILEGES'=>'Privilegien',
'LBL_CUSTOM_ACCESS_PRIVILEGES'=>'Benutzerdefinierte Zugangsregeln',
'LBL_ADD_PRIVILEGES_BUTTON'=>'erstelle Privilegien',
'LBL_RULE_NO'=>'Regelnr.',
'LBL_CAN_BE_ACCESSED'=>'kann zugegriffen werden durch',
'LBL_CUSTOM_ACCESS_MESG'=>'Keine benutzerdefinierte Zugangsregel definiert. ',
'LNK_CLICK_HERE'=>'Klick hier',
'LBL_CREATE_RULE_MESG'=>'um eine neue Regel zu erstellen',
'LBL_RECALC_MSG'=>'Sind Sie sicher, dass Sie die globalen Rechte neu berechnen lassen wollen?',
'LBL_YES'=>'Ja',
'LBL_NO'=>'Nein',
'LBL_IN_PERMISSION'=>'mit der Erlaubnis',
'LBL_RELATED_MODULE_RIGHTS'=>'Rechte bezogener Module',
'LBL_USR_CAN_ACCESS'=>'Benutzerberechtigung ',
'LBL_USR_OTHERS'=>' für andere Benutzer ',
'LBL_USR_CANNOT_ACCESS'=>'Benutzer können auf andere Benutzer nicht zugreifen ',
 
'LBL_ORG_SHARING_PRIVILEGES'=>'CRM Module',
'LBL_EDIT_PERMISSIONS'=>'Ändere Berechtigungen',
'LBL_SAVE_PERMISSIONS'=>'Berechtigungen Speichern',
'LBL_READ_ONLY'=>'Öffentlich: Nur Lesen',
'LBL_EDIT_CREATE_ONLY'=>'Öffentlich: Lesen, Erstellen/Bearbeiten',
'LBL_READ_CREATE_EDIT_DEL'=>'Öffentlich: Lesen, Erstellen/Bearbeiten, Löschen',
'LBL_PRIVATE'=>'Privat',
 
'Public: Read Only'=>'Öffentlich: Nur Lesen',
'Public: Read, Create/Edit'=>'Öffentlich: Lesen, Erstellen/Bearbeiten',
'Public: Read, Create/Edit, Delete'=>'Öffentlich: Lesen, Erstellen/Bearbeiten, Löschen',
'Private'=>'Privat',
'Hide Details'=>'Verberge Details',
'Hide Details and Add Events'=>'Verberge Details und erstelle Ereignisse',
'Show Details'=>'Zeige Details',
'Show Details and Add Events'=>'Zeige Details und erstelle Ereignisse',

//Added for User Login History While moving from User to Settings
'LBL_LOGIN_HISTORY'=>'Login Historie',
//Sharing Access module moved to Setting
'Read/Write'=>'Lesen/Schreiben',
'Read Only '=>'Nur Lesen ',
'LBL_GROUP'=>'Gruppe',
'LBL_ACCESS_RIGHTS_FOR_MODULES'=>'Zugangsrechte zu relativen Modulen',
'LBL_ADD_RULE'=>'erstelle Regel',
'LBL_ADD_CUSTOM_RULE'=>'erstelle benutzerdefinierte Regel',
'LBL_RULE_CONSTRUCTION'=>'Regelgenerator',
'LBL_STEP'=>'Schritt',
'LBL_SELECT_ENTITY'=>'Bitte einen Eintrag markieren',
'LBL_CAN_BE_ACCESSED_BY'=>'Kann zugegriffen werden durch',
'LBL_PERMISSIONS'=>'Rechte',
'LBL_DOC_MSWORD'=>'Fehler: Die Datei muss ein Dokument im MS Word Format sein.',
'LBL_NODOC'=>'Keine doc Datei in diesem Verzeichnis gefunden. Bitte noch einmal versuchen!',

//Added for error messages on Company Info.
'LOGO_ERROR'=>'Ein Logo muss im Dateiformat jpeg oder png vorliegen.',
'Error_Message'=>'Fehlernachricht',
'Invalid_file'=>'falsches Dateiformat ODER',
'File_has_no_data'=>'Datei ist leer',
'Sorry'=>'Das geht leider nicht',
'uploaded_file_exceeds_maximum_limit'=>'die Datei ist zu gross.',
'try_file_smaller'=>'Bitte nutzen Sie eine Datei mit max. 800000 Bytes',
'Problems_in_upload'=>'Es gibt Probleme beim Laden der Datei.',
'Please_try_again'=>'Bitte noch einmal versuchen.',
//5.0.3 fixes
'LBL_TESTMAILSTATUS'=>'teste Mail Status: ',
'LBL_CHECK_ASSIGNEDTO_MAILID'=>'Bitte prüfen Sie die zugewiesene E-Mail Adresse.',
'LBL_MAILSENDERROR'=>'Es wurde erfolglos versucht, eine E-Mail zu der Adresse Ihres CRM Administrators zu senden. Bitte prüfen Sie die zugewiesene E-Mail Adresse und Ihre Servereinstellungen.',
'LBL_RECORD_NOEXIST'=>'Daten nicht vorhanden',
'LBL_ENTER_PROFILE'=>'Profilenamen eingeben',
'LBL_ENABLE'=>'Aktivierung der',
'LBL_DISABLE'=>'Sperren',
'LBL_PROXY'=>'Proxy',
'LBL_FIELDS_TO_BE_SHOWN'=>'angezeigte Felder',
//Added for alerts
'SPECIFY_FILE_TO_MERGE' => 'Bitte eine Datei auswählen',
'FILESIZE_EXCEEDS_INFO_CONFIG_INC' => 'Die Datei ist zu gross. Bitte benutzen Sie eine kleinere Datei oder ändern Sie die Angaben in der config.inc.php.',
'FILESIZE_EXCEEDS_INFO_PHP_INI' => 'Die Datei ist zu gross. Bitte benutzen Sie eine kleinere Datei oder ändern Sie die Angaben in der config.inc.php.',
'PROBLEMS_IN_FILEUPLOAD' => 'Probleme beim Laden der Datei. Bitte noch einmal versuchen!',

//Added fields for Invoice Number labels
'LBL_CUSTOMIZE_INVOICE_NUMBER'=>'Rechnungsnummern',
'LBL_CUSTOMIZE_INVOICE_NUMBER_DESCRIPTION'=>'Rechnungsnummer anpassen',
'LBL_CUSTOM_INVOICE_NUMBER_VIEW'=>'Rechnungsnummer anpassen',
'LBL_CUSTOMINVOICE_STRING'=>'Bezeichnung',
'LBL_CUSTOMINVOICE_NUMBER'=>'angepasste Rechnungsnummer',
'LBL_INVOICE_NUMBER_PREVIEW'=>'Vorschau',
'LBL_INVOICE_NUMBER_BUTTON'=>'Rechnungsnummer aktualisieren',
'LBL_PROXY_AUTHENTICATION_REQUIRED'=>'Proxy Authentifikation erforderlich',
'LBL_ENABLE_FTP' => 'FTP Support muss in php zugelassen sein',

//Added for Role Labels
'LBL_ADD_ROLE'=>'Rolle hinzufügen',
'LBL_EDIT_ROLE'=>'Rolle bearbeiten',
'LBL_MOVE_ROLE'=>'Rolle verschieben',
'LBL_BACKUP_DESC'=>' Sie können ein vollständiges Backup Ihrer Datenbank auf einen FTP Server machen. Dieses Backup wird dann automatisch ausgeführt, wenn sich der admin Nutzer ausloggt. Sie müssen sicherstellen, dass Ihr FTP Server über ausreichend Speicherplatz verfügt. Die Backup Datei liegt dann im folgenden Format vor: "backup-datum-zeit.sql".',

// Added/Updated for vtiger CRM 5.0.4
'LBL_SUPPORT_NOTICIATION'=>'Ende Supportfall',
'LBL_SUPPORT_NOTICIATION_MONTH'=>'Supportfall ist in einem Monat beendet' ,
'LBL_SUPPORT_DESCRIPTION'=>'Mitteilung über einen abgeschlossenen Supportfall',
'LBL_SUPPORT_DESCRIPTION_MONTH'=>'Mitteilung über einen Supportfall, der in einem Monat endet',
'LBL_SELECT_ROLE'=>'Rolle auswählen',
'LBL_TEMPLATE'=>'Vorlage',
'LBL_SELECT_EMAIL_TEMPLATE_FOR'=>'Wähle die E-Mail Vorlage für',

'ERR_CUSTOM_FIELD_WITH_NAME'=>'Ein benutzerdefiniertes Feld mit dem Namen ',
'ERR_ALREADY_EXISTS'=>' existiert bereits.',
'ERR_SPECIFY_DIFFERENT_LABEL'=>'Bitte eine andere Bezeichung auswählen',
'LBL_TOOLS_TO_BE_SHOWN'=>'Werkzeuge zur Anzeige',
'LBL_PICKLIST_GLOBAL_DELETE'=>'globales Löschen',
'LBL_PICKLIST_TRANSFER'=>'übertrage die Einträge von ',
'LBL_REPLACE_VALUE_WITH'=>'Ersetze Einträge mit ',
'LBL_EDIT_CUSTOM_RULE'=>'Bearbeite die benutzerdefinierte Rolle',

/*for global add/delete in picklist*/
'DELETE_PICKLIST_VALUES'=>'Listeneinträge löschen',
'EDIT_PICKLIST_VALUE'=>'Listeneintrag bearbeiten',
'ADD_PICKLIST_VALUES'=>'Listeneintrag hinzufügen',
'LBL_PICKLIST_ADDINFO'=>'Geben Sie Zeile für Zeile Ihe Einträge ein',
'LBL_SELECT_ROLES'=> 'Wählen Sie die Rolle zu der die Einträge gehören sollen',
'LBL_EXISTING_PICKLIST_VALUES'=>'vorhandene Listeneinträge',
'LBL_SELECT_PICKLIST'=>'Liste auswählen',

// Added after 5.0.4 GA

'LBL_GENERAL_FIELDS'=>'Allgmeine Felder',

'LBL_CANCEL_BUTTON'=>'Abbrechen',

//Added fields for Inventory Number labels
'LBL_CUSTOMIZE_INVENTORY_NUMBER'=>'Sequenz bearbeiten',
'LBL_CUSTOMIZE_INVENTORY_NUMBER_DESCRIPTION'=>'Sequenz anpassen',
'LBL_CUSTOM_QUOTE_NUMBER_VIEW'=>'Angebotsnummer anpassen',
'LBL_CUSTOMQUOTE_STRING'=>'Bezeichung',
'LBL_CUSTOMQUOTE_NUMBER'=>'Nummer',
'LBL_QUOTE_NUMBER_PREVIEW'=>'Vorschau',
'LBL_QUOTE_NUMBER_BUTTON'=>'Angebotsnummer aktualisieren',
'LBL_CUSTOM_SO_NUMBER_VIEW'=>'Nummer der Verkaufsbestellungen anpassen',
'LBL_CUSTOMSO_STRING'=>'Bezeichung',
'LBL_CUSTOMSO_NUMBER'=>'Bestellnummer anpassen',
'LBL_SO_NUMBER_PREVIEW'=>'Preview',
'LBL_SO_NUMBER_BUTTON'=>'Bestellnummer aktualisieren',
'LBL_CUSTOM_PO_NUMBER_VIEW'=>'Bestellnummer anpassen',
'LBL_CUSTOMPO_STRING'=>'Bezeichung',
'LBL_CUSTOMPO_NUMBER'=>'Nummer',
'LBL_PO_NUMBER_PREVIEW'=>'Vorschau',
'LBL_PO_NUMBER_BUTTON'=>'Bestellnummer aktualisieren',

// Added after 5.0.4 GA

// Added for Multi-Currency Support
'LBL_TRANSFER_CURRENCY'=>'Währung übertragen',
'LBL_CURRENT_CURRENCY'=>'aktuelle Währung',

//Added for new backup labels
'LBL_LOCAL'=>'lokal',
'LBL_BACKUP'=>'Backup',
'LBL_BACKUP_LOCATION'=>'Backup Location',

'LBL_LAYOUT_EDITOR'=>'Layout Editor',
'LBL_LAYOUT_EDITOR_DESCRIPTION'=>'Gestalten und Bearbeiten Sie das Layout für jedes Modul',
'LBL_Show'=>'Anzeigen',
'LBL_Hide'=>'Verbergen',

// vtlib customization: Language Stings
'VTLIB_LBL_MODULE_MANAGER'=>'Modulmanager',
'VTLIB_LBL_MODULE_MANAGER_DESCRIPTION'=>'Verwalten Sie Zusatzmodule für das CRM',
'VTLIB_LBL_MODULE_MANAGER_CUSTOMMOD'=>'Benutzerdefinierte Module',
'VTLIB_LBL_MODULE_MANAGER_STANDARDMOD'=>'Standardmodule',
'VTLIB_LBL_MODULE_MANAGER_NOMODULES'=>'Keine benutzerdefinierte Module gefunden!',

// vtmailscanner START
'LBL_MAIL_SCANNER'=>'E-Mail Konverter',
'LBL_MAIL_SCANNER_DESCRIPTION'=>'Konfigurieren Sie die Scan Parameter für die Mailbox',
'LBL_SCAN_NOW'=>'jetzt scannen',
'LBL_RULE'=>'Regel',
'LBL_SETUP'=>'erstelle',
'LBL_CONFIGURE'=>'Konfiguriere',
'LBL_MAILBOX' => 'Mailbox',
'LBL_INFORMATION' => 'Information',
'LBL_SCANNER' => 'Konverter',
'LBL_SERVER'  => 'Server',
'LBL_PROTOCOL'=> 'Protokol',
'LBL_PASSWORD'=> 'Passwort',
'LBL_TYPE' => 'Typ',
'LBL_SSL' => 'SSL',
'LBL_METHOD'=> 'Methode',
'LBL_VAL_SSL_CERT'=>'SSL Zertifikat überprüfen',
'LBL_DONOT_VAL_SSL_CERT'=>'SSL Zertifikat nicht überprüfen',
'LBL_STATUS'=>'Status',
'LBL_ENABLE'=>'zulassen',
'LBL_DISABLE'=>'sperren',
'LBL_CONNECT'=>'verbinde',
'LBL_URL_CAPS'=>'URL',
'LBL_ENABLED'=>'zugelassen',
'LBL_DISABLED'=>'gesperrt',
'LBL_RULES'=>'Regeln',
'LBL_FOR'=>'für',

'LBL_FROM'=>'Von',
'LBL_TO'=>'An',

'LBL_ACTION'=>'Aktion',
'LBL_CREATE'=>'erstelle',
'LBL_TICKET'=>'Ticket',
'LBL_ADD'=>'erstelle',

'LBL_CONTACT'=>'Person',
'LBL_ACCOUNT'=>'Organisation',

'LBL_FROM_CAPS'=>'Von',
'LBL_TO_CAPS'=>'An',
'LBL_TO_SMALL'=>'an',

'LBL_CONTAINS'=>'beinhalted',
'LBL_EQUALS'=>'gleich zu',

'LBL_BEGINS'=>'beginnt mit',

'LBL_REGEX'=>'Regex',
'LBL_ENDS'=>'endet',
'LBL_BODY'=>'Inhalt',

'LBL_NOT'=>'Nicht',

'LBL_ALL' => 'alle',
'LBL_ANY'=>'jede',
'LBL_CONDITION'=>'Bedingungen',
'LBL_ACTION'=>'Aktion',
'LBL_MOVE'=>'verschieben',
'LBL_UP'=>'aufwärts',
'LBL_DOWN'=>'abwärts',
'LBL_PRIORITY'=>'Priorität',
'LBL_UPDATE'=>'Update',
'LBL_SELECT'=>'organisiere',
'LBL_FOLDERS'=>'Verzeichnisse',
'LBL_UNSELECT'=>'abwählen',
'LBL_MATCH'=>'Match',
'LBL_SCANNING'=>'Scannen',
'LBL_LOOKFOR'=>'suche nach',
'LBL_UNREAD'=>'ungelesenen',
'LBL_READ'=>'gelesen',
'LBL_AFTER_SCAN'=>'nach dem Scan',
'LBL_MESSAGES_FROM_LASTSCAN'=>'Nachrichten vom letzten Scan',
'LBL_MARK_MESSAGE_AS'=>'markiere die Nachricht als',

//Added for the workflow module
'LBL_LIST_WORKFLOWS'=>'Liste der Workflows',
'LBL_LIST_WORKFLOWS_DESCRIPTION' => 'Anzeige und Gestaltung von Workflows für das CRM',
'LBL_TASK_TITLE'=>'Aufgabenbezeichung',
'LBL_PARENT_WORKFLOW'=>'übergeordneter Workflow',
'MSG_EXECUTE_TASK_DELAY'=>'führe die Aufgabe verzögert aus',
'LBL_AFTER'=>'nach',
'LBL_BEFORE'=>'vor',
'LBL_TASK_OPERATIONS'=>'Aufgabenbeschreibung',
'LBL_CREATE_TASK'=>'Aufgabe erstellen',
'LBL_CREATE_TASK_OF_TYPE'=>'erstelle eine Aufgabe vom Typ',
'LBL_SUMMARY'=>'Zusammenfassung',
'LBL_WHEN_TO_RUN_WORKFLOW'=>'Wann soll der Workflow ausgeführt werden',
'LBL_ONLY_ON_FIRST_SAVE'=>'nur beim ersten Speichern',
'LBL_UNTIL_FIRST_TIME_CONDITION_TRUE'=>'Solange bis die gesetzte Bedingung eintritt',
'LBL_EVERYTIME_RECORD_SAVED'=>'jedesmal wenn ein Datensatz gespeichert wird',
'LBL_ON_MODIFY' => 'jedemal wenn ein Datensatz geändert wird',
'LBL_CONDITIONS'=>'Bedingungen',
'LBL_NEW_CONDITION_BUTTON_LABEL'=>'neue Bedingung',
'LBL_TASKS'=>'Aufgaben',
'LBL_NEW_TASK_BUTTON_LABEL'=>'neue Aufgabe',
'LBL_TASK'=>'Aufgabe',
// END
//Added for vantage customization (Mandatory fields) -- Pavani
'LBL_MANDATORY_FIELDS'=>'Pflichtfelder',
'LBL_MANDATORY_FIELDS_DESCRIPTION'=>'Verwalte die Pflichtfelder für alle Module',
// Module Sequence Numbering
'LBL_CUSTOMIZE_MODENT_NUMBER'=>'Anpassen der Nummerierung',
'LBL_CUSTOMIZE_MODENT_NUMBER_DESCRIPTION'=>'Nummerieren Sie die Datensätze nach Ihren Vorlagen',
// END

//added for softphone integration
'LBL_SOFTPHONE_SERVER_SETTINGS'=>'SoftPhone Server Einstellungen',
'LBL_SOFTPHONE_SERVER_SETTINGS_DESCRIPTION'=>'konfiguren Sie hier die Parameter',
'ASTERISK_SERVER_IP'=>'Asterisk Server IP ',
'ASTERISK_PORT'=>'Asterisk Server Port',
'ASTERISK_USERNAME'=>'Asterisk Nutzrname',
'ASTERISK_PASSWORD'=>'Asterisk Passwort',
'ASTERISK_SERVER_IP_TITLE'=>'Die URL des Asterisk Server',
'ASTERISK_PORT_TITLE'=>'The port where asterisk call manager API can connect to Asterisk (default 5038)',
'ASTERISK_USERNAME_TITLE'=>'The asterisk username (generally the admin username)',
'ASTERISK_PASSWORD_TITLE'=>'Password for the asterisk user',
'LBL_CANCEL_BUTTON'=>'Abbrechen',
'ASTERISK_VERSION' => 'Asterisk Version',
'ASTERISK_VERSION_TITLE'=>'Wählen Sie Ihre Asterisk Version hier. Wenn Sie nicht sicher sind wählen Sie 1.4.',
'ASTERISK_CONFIGURATION'=>'Asterisk Konfiguration',
//softphone integration ends
'LBL_SELECT_FIELD_TO_MOVE' => 'Wählen Sie die Felder zum Verschieben',
'VTLIB_LBL_SELECT_PACKAGE_FILE'=>'Wählen Sie die Paketdatei',
'VTLIB_LBL_FILE_LOCATION'=>'Dateispeicherplatz:',
'VTLIB_LBL_PACKAGE_FILE_HELP'=>'CRM Module ist als ZIP Datei gepackt.',
'VTLIB_LBL_IMPORT_FAILURE'=>'Import Fehler',
'VTLIB_LBL_INVALID_FILE'=>'ungültige Datei',
'VTLIB_LBL_INVALID_IMPORT_TRY_AGAIN'=>'Win Modul für den Import muss ausgewählt werden!',
'VTLIB_LBL_UNABLE_TO_UPLOAD'=>'Aktualisierung für das',
'VTLIB_LBL_UNABLE_TO_UPLOAD2'=>'Paket auf dem Server nicht möglich!',
'VTLIB_LBL_VERIFY_IMPORT_DETAILS'=>'Überprüfe Import Details',
'VTLIB_LBL_MODULE_NAME'=>'Modul Name',
'VTLIB_LBL_MODULE_DIR'=>'Module Verzeichnis',
'VTLIB_LBL_REQ_VTIGER_VERSION'=>'CRM Version',
'VTLIB_LBL_LICENSE'=>'Lizenz',
'VTLIB_LBL_LICENSE_ACCEPT_AGREEMENT'=>'Ich akzeptiere die Lizenzbestimmungen.',
'VTLIB_LBL_PROCEED_WITH_IMPORT'=>'Wollen Sie mit dem Import fortfahren?',
'VTLIB_LBL_IMPORTING_MODULE_START'=>'Importiere das Modul ...',
'VTLIB_LBL_WARNING'=>'Warnung',
'VTLIB_LBL_NOT_WRITEABLE'=>'nicht schreibbar',
'VTLIB_LBL_PACKAGE_VERSION'=>'Version',

'LBL_UPGRADE'=>'Upgrade',
'VTLIB_LBL_UPDATE_FAILURE'=>'Upgrade Fehler',
'VTLIB_LBL_MODULENAME_MISMATCH'=>'Modulname stimmt nicht überein',
'VTLIB_LBL_TRY_AGAIN'=>'Noch einmal versuchen',
'VTLIB_LBL_VERIFY_UPDATE_DETAILS'=>'Überprüfe Upgrade Details',
'VTLIB_LBL_PROCEED_WITH_UPDATE'=>'Wollen Sie mit dem Upgrade fortfahren?',
'VTLIB_LBL_UPDAING_MODULE_START'=>'Updating Modul ...',
'VTLIB_LBL_EXISTS'=>'exisiert',
'VTLIB_LBL_NOT_PRESENT'=>'nicht vorhanden',
'VTLIB_LBL_INST_VERSION'=>'installierte Version',
'VTLIB_LBL_MATCHES_PACKAGE_VERSION'=>'Paketversion stimmt überein',
'VTLIB_LBL_CANNOT_UPGRADE'=>'Upgrade nicht möglich!',
// END

//User group fixes
'LBL_USERNAME_EXIST' => 'Es gibt bereits einen Nutzer mit diesem Namen!',
'LBL_GROUPNAME_EXIST' => 'Es gibt bereits eine Gruppe mit diesem Namen!',
'LBL_ROLENAME_EXIST' => 'Es gibt bereits eine Rolle mit diesem Namen!',

//layout editor
'LBL_MOVE_FIELDS' => 'Felder verschieben',
'NO_HIDDEN_FIELDS' => 'keine verborgenen Felder',
'LBL_RELATED_LIST' => 'bezogene Listen',
'LBL_ADD_BLOCK' => 'Block hinzufügen',
'HIDDEN_FIELDS' => 'verborgenen Felder',
'DOWN'=> 'runter',
'UP'=> 'hoch',
'RIGHT' => 'rechts',
'LEFT' => 'links',
'LBL_EDIT_PROPERTIES' => 'Eigenschaften bearbeiten',
'LBL_MANDATORY_FIELD' => 'Pflichtfelder',
'LBL_ACTIVE' => 'Aktiv',
'LBL_QUICK_CREATE' => 'schnell erstellen',
'LBL_MASS_EDIT' => 'Massenänderung',
'LBL_BLOCK_NAME' => 'Blockname',
'AFTER' => 'nach',
'ADD_BLOCK' => 'Block hinzufügen',
'ARRANGE_RELATEDLIST' => 'bezogene Listen arrangieren',
'CUSTOMFIELD_MAPPING' => 'Zuordnung von benutzerdefinierten Feldern',
'LBL_MAPPED_FIELDS' => 'zugeordnete Felder',
'LEADS_CUSTOM_FIELD_MAPPING_DESCRIPTION' => 'Ordnen Sie Lead Felder Organisationen, Personen und Potentialen zu',
'LEADS_CUSTOM_FIELD_MAPPING'=> 'Zuordnung von Lead Feldern',
'LBL_CALENDER_CUSTOMFIELDS' => 'Kalenderfelder',
'LBL_CALENDER_CUSTOMFIELDS_DESCRIPTION' => 'Sie können benutzerdefinierte Felder für die Kalender erstellen.',
'LBL_GO_BACK'=>'zurück',

//Added fix for: 5418
'LBL_USE_PREFIX' => 'Präfix benutzen',
'LBL_START_SEQ' => 'Startsequenz',
'LBL_MODULE_NUMBERING' => 'Modul Nummern',
'LBL_FAILED' => 'Failed',
'LBL_DONE' => 'erledigt',
'LBL_IN_USE' => 'in Benutzung',
'LBL_MODULE_NUMBERING_FIX_MISSING' => 'fehlende Datensatzsequenz jetzt aktualisieren',

//Added for: 5473
'LBL_SHARING_ACCESS_HELPNOTE' => 'Nachdem Sie Änderungen duchgeführt haben, müssen Sie den Neu Berechnen Button klicken.',

//for customer portal extension module
'PORTAL_EXTENSION_DESCRIPTION'=>'Gestattet das Kundenportal zu konfigurieren',
'LBL_CUSTOMER_PORTAL'=> 'Kundenportal',

'Assets' => 'Bestand',

// Customization
'LBL_PUBLISHER' => 'Herausgeber',
'LBL_PUBLISHED_ON' => 'veröffentlicht am',
'LBL_LICENSE'   => 'Lizenz',
'LBL_EXTENSION_FILE_DOWNLOAD_FAILED' => 'Das Erweiterungs-Packet konnte nicht heruntergeladen werden!',
'LBL_DEFAULT'=>' Als Standard wird der Postausgangsserver mit dem Server od1.vtiger.com konfiguriert. Um zu verhindern, dass gesendete E-Mails als Spam erkannt werden, sollten Sie einen der folgenden implementieren.',
'LBL_OPTIONS1'=>'Senden Sie E-Mails von Ihren E-Mail-Server<br>
				- Geben Sie die Postausgangsserver-Einstellungen (Servername, Benutzer, Password) mit dem selben Benutzer, wie Sie als "Von"-E-Mail-Adresse eingetragen haben.',
'LBL_OPTIONS2'=>"Fügen Sie od1.vtiger.com als authorisierter Server für Ihre Domain hinzu.<br>
				- Wenn Sie den vtiger Server als Postausgangsserver behalten wollen, empfehlen wir, dass Sie Ihren Domain-SPF-Eintrag so konfigurieren, dass der vtiger Server als gültiger Absender gilt.
				  Für weitere Informationen zum Einrichten des SPF-Eintrages senden Sie bitte eine E-Mail an od-support@vtiger.com.",
'LBL_ALREADY_EXISTS' => 'Existiert bereits',
'LBL_EXTENSION_INCOMPATIBLE' => 'Erweiterung nicht kompatibel',
'LBL_INSTALL' => 'Installieren',
'LBL_DEFAULT_SETTINGS_BUTTON_TITLE' => 'Zum Standard zurücksetzen',
'LBL_CONFIRM_DEFAULT_SETTINGS' => 'Sind Sie sicher, dass Sie die Server-Einstellungen zum Standard zurück setzen wollen?',
'EXISTING_DEFAULT_VALUES' => 'Die Server-Einstellungen wurden bereits zum Standard zurückgesetzt.',
'LBL_NOTE' => 'Hinweis:',
'LBL_HIDE' => 'Verberge Details',
'LBL_SHOW' => 'Zeige Details',
// END
'LBL_USER_ADDITION_INFO'=>"Um einen neuen Benutzer hinzuzufügen, klicken Sie bitte auf  
			   <span style='font-style:italic;color:blue;'>OD-Einstellungsmenü -> On Demand Admin -> Benutzer hinzufügen / einladen </span>",

'LBL_READ_ONLY_ACCESS_MSG' => 'Lesezugriff',
'LBL_READ_WRITE_ACCESS_MSG' => 'Lese- und Schreibzugriff',

'LBL_DEFAULT_VALUE' => 'Standardwerte',

'LBL_DESCRIPTION_Public: Read Only'=>'Benutzer können andere Benutzer nur ansehen ',
'LBL_DESCRIPTION_Public: Read, Create/Edit'=>'Benutzer können andere Benutzer ansehen, bearbeiten und anlegen ',
'LBL_DESCRIPTION_Public: Read, Create/Edit, Delete'=>'Benutzer können andere Benutzer ansehen, bearbeiten, anlegen und löschen ',

// For Dependency picklist
'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Einstellungen der Abhängigkeiten von Auswahllisten',
'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Erstelle Abhängigkeiten zwischen den Werten der Auswahllisten in jedem Modul',

'Settings' => 'Einstellungen',
'LBL_ERR_TAX_LABEL_ALREADY_EXISTS' => 'Diese Mwst. ist bereits vorhanden.',
'LBL_ERR_SOME_TAX_LABELS_ALREADY_EXISTS' => 'Einige Mwst. Beschriftungen sind bereits vorhanden, deshalb kann es nicht gespeichert werden.',

'Configuration Editor'=>'Konfigurations Editor',
'Update configuration file of the application'=>'Verändern Sie globale Einstellungen für das CRM',
);
?>